Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/windirstat/llfio.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNiall Douglas (s [underscore] sourceforge {at} nedprod [dot] com) <spamtrap@nedprod.com>2020-01-09 13:17:56 +0300
committerNiall Douglas (s [underscore] sourceforge {at} nedprod [dot] com) <spamtrap@nedprod.com>2020-01-09 13:17:56 +0300
commit0b956868ebf3e31e38197342f7cd6f2f4a431b5d (patch)
tree8199765097ffce60007ce4d373157a608c08d974 /include/llfio/v2.0/symlink_handle.hpp
parent379075e89b5a51473e063952967467b4cb4ac952 (diff)
Rename random_*() handle constructors to uniquely_named_*(), as per LEWG-I feedback.
Diffstat (limited to 'include/llfio/v2.0/symlink_handle.hpp')
-rw-r--r--include/llfio/v2.0/symlink_handle.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llfio/v2.0/symlink_handle.hpp b/include/llfio/v2.0/symlink_handle.hpp
index f7bf57c4..722eca4c 100644
--- a/include/llfio/v2.0/symlink_handle.hpp
+++ b/include/llfio/v2.0/symlink_handle.hpp
@@ -404,7 +404,7 @@ public:
*/
LLFIO_MAKE_FREE_FUNCTION
static LLFIO_HEADERS_ONLY_MEMFUNC_SPEC result<symlink_handle> symlink(const path_handle &base, path_view_type path, mode _mode = mode::read, creation _creation = creation::open_existing, flag flags = flag::none) noexcept;
/*! Create a symlink handle creating a randomly named symlink on a path.
The symlink is opened exclusively with `creation::only_if_not_exist` so it
will never collide with nor overwrite any existing symlink.
@@ -412,7 +412,7 @@ public:
or failure to allocate memory.
*/
LLFIO_MAKE_FREE_FUNCTION
- static inline result<symlink_handle> random_symlink(const path_handle &dirpath, mode _mode = mode::write, flag flags = flag::none) noexcept
+ static inline result<symlink_handle> uniquely_named_symlink(const path_handle &dirpath, mode _mode = mode::write, flag flags = flag::none) noexcept
{
try
{
@@ -404,7 +404,7 @@ public:
LLFIO_MAKE_FREE_FUNCTION
static LLFIO_HEADERS_ONLY_MEMFUNC_SPEC result<symlink_handle> symlink(const path_handle &base, path_view_type path, mode _mode = mode::read, creation _creation = creation::open_existing, flag flags = flag::none) noexcept;
- /*! Create a symlink handle creating a randomly named symlink on a path.
+ /*! Create a symlink handle creating a uniquely named symlink on a path.
The symlink is opened exclusively with `creation::only_if_not_exist` so it
will never collide with nor overwrite any existing symlink.